@@ -66,6 +66,7 @@
 #define CH_TXTPLAIN	(1<<11) /* generate text/plain MIME headers */
 #define CH_NOLEN	(1<<12) /* don't write Content-Length: and Lines: */
 #define CH_WEED_DELIVERED (1<<13) /* weed eventual Delivered-To headers */
+#define CH_FORCE_FROM	(1<<14)	/* give CH_FROM precedence over CH_WEED? */
 
 /* flags for mutt_enter_string() */
 #define  M_ALIAS   1      /* do alias "completion" by calling up the alias-menu */
@@ -227,7 +228,8 @@ enum
 {
 
 #ifdef _PGPPATH
-  OPT_VERIFYSIG, /* verify PGP signatures */
+  OPT_VERIFYSIG,      /* verify PGP signatures */
+  OPT_PGPTRADITIONAL, /* create old-style PGP messages */
 #endif
 
   OPT_PRINT,
@@ -242,7 +244,8 @@ enum
   OPT_REPLYTO,
   OPT_ABORT,
   OPT_RECALL,
-  OPT_SUBJECT
+  OPT_SUBJECT,
+  OPT_MAX
 };
 
 /* flags to ci_send_message() */
@@ -274,6 +277,7 @@ enum
   OPTCOLLAPSEUNREAD,
   OPTCONFIRMAPPEND,
   OPTCONFIRMCREATE,
+  OPTDELETEUNTAG,
   OPTEDITHDRS,
   OPTENCODEFROM,
   OPTFASTREPLY,
@@ -282,7 +286,6 @@ enum
   OPTFORCENAME,
   OPTFORWATTACH,
   OPTFORWDECODE,
-  OPTFORWWEEDHEADER,
   OPTFORWQUOTE,
   OPTHDRS,
   OPTHEADER,
@@ -313,6 +316,7 @@ enum
   OPTRESOLVE,
   OPTREVALIAS,
   OPTREVNAME,
+  OPTRFC2047PARAMS,
   OPTSAVEADDRESS,
   OPTSAVEEMPTY,
   OPTSAVENAME,
@@ -406,7 +410,6 @@ typedef struct list_t
 } LIST;
 
 #define mutt_new_list() safe_calloc (1, sizeof (LIST))
-void mutt_add_to_list (LIST **, BUFFER *);
 void mutt_free_list (LIST **);
 int mutt_matches_ignore (const char *, LIST *);
 
@@ -461,6 +464,7 @@ typedef struct content
   unsigned int binary : 1; /* long lines, or CR not in CRLF pair */
   unsigned int from : 1;   /* has a line beginning with "From "? */
   unsigned int dot : 1;    /* has a line consisting of a single dot? */
+  unsigned int cr : 1;     /* has CR, even when in a CRLF pair */
 } CONTENT;
 
 typedef struct body
@@ -498,7 +502,7 @@ typedef struct body
 				 * encoding update.
 				 */
   
-  unsigned int type : 3;        /* content-type primary type */
+  unsigned int type : 4;        /* content-type primary type */
   unsigned int encoding : 3;    /* content-transfer-encoding */
   unsigned int disposition : 2; /* content-disposition */
   unsigned int use_disp : 1;    /* Content-Disposition field printed? */
@@ -509,12 +513,17 @@ typedef struct body
   unsigned int tagged : 1;
   unsigned int deleted : 1;	/* attachment marked for deletion */
   unsigned int noconv : 1;	/* don't do character set conversion */
+
+#ifdef _PGPPATH
+  unsigned int goodsig : 1;	/* good PGP signature */
+#endif
+
 } BODY;
 
 typedef struct header
 {
 #ifdef _PGPPATH
-  unsigned int pgp : 3;
+  unsigned int pgp : 4;
 #endif
 
   unsigned int mime : 1;    /* has a Mime-Version header? */
