@@ -295,12 +295,12 @@ void mx_unlink_empty (const char *path)
 {
   int fd;
 #ifndef USE_DOTLOCK
-  char b;
+  struct stat sb;
 #endif
 
   if ((fd = open (path, O_RDWR)) == -1)
     return;
-  
+
   if (mx_lock_file (path, fd, 1, 0, 1) == -1)
   {
     close (fd);
@@ -310,11 +310,12 @@ void mx_unlink_empty (const char *path)
 #ifdef USE_DOTLOCK
   invoke_dotlock (path, DL_FL_UNLINK, 1);
 #else
-  if  (read (fd, &b, 1) != 1)
+  if (fstat (fd, &sb) == 0 && sb.st_size == 0)
     unlink (path);
 #endif
 
   mx_unlock_file (path, fd, 0);
+  close (fd);
 }
 
 /* try to figure out what type of mailbox ``path'' is
