@@ -765,10 +765,10 @@ static int match_reference (regex_t *rx, LIST *refs)
 int mutt_is_list_recipient (int alladdr, ADDRESS *a1, ADDRESS *a2)
 {
   for (; a1 ; a1 = a1->next)
-    if (alladdr ^ mutt_is_mail_list (a1))
+    if (alladdr ^ mutt_is_subscribed_list (a1))
       return (! alladdr);
   for (; a2 ; a2 = a2->next)
-    if (alladdr ^ mutt_is_mail_list (a2))
+    if (alladdr ^ mutt_is_subscribed_list (a2))
       return (! alladdr);
   return alladdr;
 }
